<?php
/** Chamorro (Chamoru)
 *
 * See MessagesQqq.php for message documentation incl. usage of parameters
 * To improve a translation please visit http://translatewiki.net
 *
 * @ingroup Language
 * @file
 *
 * @author Diego Grez
 * @author Gadao01
 * @author Jatrobat
 * @author Magalahi
 * @author MisterWiki
 */

$namespaceNames = array(
	NS_MEDIA            => 'Media',
	NS_SPECIAL          => 'Espesiat',
	NS_TALK             => 'Kombetsasion',
	NS_USER             => 'Muna\'sesetbi',
	NS_USER_TALK        => 'Kombetsasion_ni_muna\'sesetbi',
	NS_PROJECT_TALK     => 'Kombetsasion_nu_$1',
	NS_FILE             => 'Litratu',
	NS_FILE_TALK        => 'Kombetsasion_ni_litratu',
	NS_HELP             => 'Ayudo',
	NS_HELP_TALK        => 'Kombetsasion_ni_ayudo',
	NS_CATEGORY         => 'Katigoria',
	NS_CATEGORY_TALK    => 'Kombetsasion_ni_katigoria',
);

$messages = array(
# User preference toggles
'tog-underline' => "Na'raya i inachetton:",
'tog-hideminor' => "Nå'na' i mandikike' na tinilaika siha gi påhinan tinilaika gi halacha",
'tog-extendwatchlist' => "Na'ladångkolu i listan pinilan para u na'annok i manaplikayon na tinilaika siha",
'tog-usenewrc' => "I manmana'lamaolek na tinilaika (JavaScript)",
'tog-showtoc' => "Na'annok i fañodda'an (annai guåha mas ki 3 na titulo gi påhina)",
'tog-rememberpassword' => 'Hasso iyo-ku login gi este na komputadora (for a maximum of $1 {{PLURAL:$1|day|days}})',
'tog-watchcreations' => "Po'lo i påhina siha ni fina'tinas-hu gi iyo-ku listan pinilan.",
'tog-watchdefault' => "Po'lo i påhina siha ni hu tulaika gi iyo-ku listan pinilan.",
'tog-watchmoves' => "Po'lo i påhina siha ni hu muebi gi iyo-ku listan pinilan.",
'tog-watchdeletion' => "Po'lo i påhina siha ni hu na'suha gi iyo-ku listan pinilan.",
'tog-minordefault' => "Matka mamo'lo todu i tinilaika siha dikike'.",
'tog-previewontop' => "Na'annok i ripasu gi me'na i kahon tinilaika",
'tog-previewonfirst' => "Na'annok i ripasu gi i fine'nena na tinilaika",
'tog-enotifwatchlistpages' => "E-mail yu' anggen guåha matulaika gi iyo-ku listan pinilan",
'tog-enotifusertalkpages' => "E-mail yu' anngen guåha matulaika gi påhinan kombetsasion-hu.",
'tog-enotifminoredits' => "E-mail yu' lokkue' ni mandikike' na tinilaika gi påhina siha.",
'tog-enotifrevealaddr' => "Na'annok iyo-ku e-mail address gi notifikasion e-mail.",
'tog-shownumberswatching' => "Na'annok i numirun muna'sesetbi siha ni mana'atan.",
'tog-forceeditsummary' => "Na'tungo' yu' annai mamo'lu yu' summaria gueku",
'tog-watchlisthideown' => "Nå'na' tinilaika-hu gi listan pinilan",
'tog-watchlisthidebots' => "Nå'na' i tinilaikan bot gi listan pinilan",
'tog-watchlisthideminor' => "Nå'na' i mandikike' na tinilaika gi listan pinilan",
'tog-ccmeonemails' => "Na'hanague yu ni kopia i e-mail siha ni hu na'hanague otru na muna'sesetbi siha",
'tog-diffonly' => "Munga mana'annok i guinaha i påhina gi papa' i diferensia",
'tog-showhiddencats' => "Na'annok i katigoria ni manmanå'na' siha",

'underline-always' => 'Kada biahi',
'underline-never' => "Ni ngai'an",
'underline-default' => 'Plantan orihinat ni Browser',

# Dates
'sunday' => 'Damenggo',
'monday' => 'Lunes',
'tuesday' => 'Mattes',
'wednesday' => 'Metkoles',
'thursday' => 'Huebes',
'friday' => 'Betnes',
'saturday' => 'Sabalu',
'sun' => 'Dam',
'mon' => 'Lun',
'tue' => 'Mat',
'wed' => 'Metk',
'thu' => 'Hueb',
'fri' => 'Bet',
'sat' => 'Sab',
'january' => 'Eneru',
'february' => 'Febreru',
'march' => 'Matso',
'april' => 'Abrit',
'may_long' => 'Måyu',
'june' => 'Hunio',
'july' => 'Hulio',
'august' => 'Agosto',
'september' => 'Septembre',
'october' => 'Oktubre',
'november' => 'Nobiembre',
'december' => 'Disiembre',
'january-gen' => 'Eneru',
'february-gen' => 'Febreru',
'march-gen' => 'Matso',
'april-gen' => 'Abrit',
'may-gen' => 'Måyu',
'june-gen' => 'Hunio',
'july-gen' => 'Hulio',
'august-gen' => 'Agosto',
'september-gen' => 'Septembre',
'october-gen' => 'Oktubre',
'november-gen' => 'Nobiembre',
'december-gen' => 'Disiembre',
'jan' => 'Ene',
'feb' => 'Feb',
'mar' => 'Mats',
'apr' => 'Abr',
'may' => 'Måy',
'jun' => 'Hun',
'jul' => 'Hul',
'aug' => 'Agos',
'sep' => 'Sep',
'oct' => 'Okt',
'nov' => 'Nob',
'dec' => 'Dis',

# Categories related messages
'pagecategories' => '{{PLURAL:$1|Kategoria|Kategoria}}',
'category_header' => 'Påhina siha gi katigoria "$1"',
'subcategories' => 'Ni dibision katigoria siha',
'category-media-header' => 'Media siha gi katigoria "$1"',
'category-empty' => "''Taya' na påhina pat media siha gi halom este na katigoria.''",
'hidden-categories' => '{{PLURAL:$1|Hinemme na katigoria|Manhinemme na kategoria siha}}',
'hidden-category-category' => 'Manhinemme na katigoria siha',
'category-subcat-count' => '{{PLURAL:$2|Guåha i sigiente na dibision kategoria gi halom este na kategoria.|Guåha i sigiente {{PLURAL:$1|na dibision kategoria|$1 na dibision kategoria siha}}, ginen $2.}}',
'category-subcat-count-limited' => 'Guåha i sigiente {{PLURAL:$1|dibision katigoria|$1 dibision katigoria siha}} gi halom este na katigoria.',
'category-article-count' => "{{PLURAL:$2|I sigiente na påhina ha' gi este na katigoria.|Guåha {{PLURAL:$1|ha' na påhina|$1 na påhina siha}} ginen $2 gi este na katigoria.}}",
'category-article-count-limited' => 'Gi este na katigoria guåha {{PLURAL:$1|na påhina|$1 na påhina siha}}.',
'category-file-count' => "{{PLURAL:$2|I sigiente atkibu ha' gi halom este na katigoria.|Guåha {{PLURAL:$1|atkibu|$1 na atkibu siha}} ginen $2 gi halom este na katigoria.}}",
'category-file-count-limited' => 'Guåha i sigiente {{PLURAL:$1|atkibu|$1 na atkibu siha}} gi halom i katigoria.',
'listingcontinuesabbrev' => 'kont.',

'about' => 'Pot',
'article' => "Påhinan fañodda'an",
'newwindow' => '(para u baba gi nuebu na bentåna)',
'cancel' => 'Kansela',
'moredotdotdot' => 'Mas...',
'mypage' => 'Påhina-hu',
'mytalk' => 'Kombetsasion-hu',
'anontalk' => 'Kuentusiyi i IP este',
'navigation' => 'Nabegasion',
'and' => '&#32;yan',

# Cologne Blue skin
'qbfind' => "Sodda'",
'qbbrowse' => 'Atan',
'qbedit' => 'Tulaika',
'qbpageoptions' => 'Este na pahina',
'qbmyoptions' => 'Påhina-hu siha',
'qbspecialpages' => 'Manespesiat na påhina',

'errorpagetitle' => 'Linachi',
'returnto' => 'Hånao tåtte para $1.',
'tagline' => 'Ginen {{SITENAME}}',
'help' => 'Ayuda',
'search' => 'Aligao',
'searchbutton' => 'Aligao',
'go' => 'Hånao',
'searcharticle' => 'Hånao',
'history' => 'Historian påhina',
'history_short' => 'Historia',
'updatedmarker' => "maribisa desde i må'pos na bisita-hu",
'printableversion' => 'Ribision imprentayon',
'permalink' => 'Inachetton petmanente',
'print' => 'Imprenta',
'edit' => 'Tulaika',
'create' => "Fa'tinas",
'editthispage' => 'Tulaika i påhina',
'create-this-page' => "Fa'tinas i påhina",
'delete' => "Na'suha",
'deletethispage' => "Na'suha i påhina",
'undelete_short' => "Po'lo tåtte {{PLURAL:$1|unu na tinilaika|$1 na tinilaika siha}}",
'protect' => 'Protehi',
'protect_change' => 'tulaika proteksion-ña',
'protectthispage' => 'Protehi i påhina este',
'unprotect' => "Na'suha proteksion-ña",
'unprotectthispage' => "Na'suha i proteksion i påhina",
'newpage' => 'Nuebu na påhina',
'talkpage' => 'Diskuti i påhina',
'talkpagelinktext' => 'Kuentusi',
'specialpage' => 'Påhina espesiat',
'personaltools' => 'Ramientan petsonat',
'postcomment' => "Fa'tinas un komentu",
'articlepage' => 'Atan i guinaha i påhina',
'talk' => 'Diskuti',
'views' => "Mali'e'-ña",
'toolbox' => 'Kåhon ramienta',
'userpage' => "Atan i påhinan muna'sesetbi",
'projectpage' => 'Atan i påhinan proyekto',
'imagepage' => 'Atan i påhinan media',
'mediawikipage' => 'Atan i påhinan mensahe',
'templatepage' => 'Atan i påhinan plantiyas',
'viewhelppage' => 'Atan i påhinan ayudo',
'categorypage' => 'Atan i påhinan katigoria',
'viewtalkpage' => 'Atan i kombetsasion',
'otherlanguages' => 'Gi otru na lengguahe siha',
'redirectedfrom' => '(Madirihi ginen $1)',
'redirectpagesub' => "Na'dirihi i påhina",
'lastmodifiedat' => "Må'pos na tinilaikan påhina gi $2, $1.",
'viewcount' => "Ma'usa este na påhina {{PLURAL:$1|un biahi|$1 na biahi}}.",
'protectedpage' => 'Maprotehi i påhina',
'jumpto' => "Ta'yuki guatu:",
'jumptonavigation' => 'nabegasion',
'jumptosearch' => 'aligao',

# All link text and link target definitions of links into project namespace that get used by other message strings, with the exception of user group pages (see grouppage).
'aboutsite' => 'Pot {{SITENAME}}',
'aboutpage' => 'Project:Pot',
'copyright' => 'Guåha i sinahguan gi halom $1.',
'copyrightpage' => "{{ns:project}}:Direchun i mantituge'",
'currentevents' => 'Estorian modetnu siha',
'currentevents-url' => 'Project:Estorian modetnu siha',
'disclaimers' => 'Diklarasion Inadahi',
'disclaimerpage' => 'Project:Diklarasion inadahi henerat',
'edithelp' => 'Ayudo tumulaika',
'helppage' => 'Help:Guinaha',
'mainpage' => 'Fanhaluman',
'mainpage-description' => 'Fanhaluman',
'policy-url' => 'Project:Areklamentu',
'portal' => 'Fanhaluman komunida',
'portal-url' => 'Project:Fanhaluman Komunida',
'privacy' => 'Areklamenton konfidensia',
'privacypage' => 'Project:Areklamenton konfidensia',

'badaccess' => 'Lachi gi petmisu',
'badaccess-group0' => "Ti siña un cho'gue i aksion ni finaisen-mu.",
'badaccess-groups' => "Solamente masedi i muna'sesetbi ni grupun $1 chumo'gue i aksion ni finaisen-mu.",

'versionrequired' => 'Manesita i rebision $1 MediaWiki',
'versionrequiredtext' => 'Manesita i rebision $1 MediaWiki para un usa i påhina. Taitai [[Special:Version|i påhinan rebision]].',

'ok' => 'OK',
'retrievedfrom' => 'Ginen "$1"',
'youhavenewmessages' => 'Guåha $1 ($2).',
'newmessageslink' => 'mannuebu na mensåhe',
'newmessagesdifflink' => 'tinilaika mas nuebu',
'youhavenewmessagesmulti' => 'Guåha nuebu mensahe-mu gi $1',
'editsection' => 'tulaika',
'editold' => 'tulaika',
'viewsourceold' => 'atan i code',
'editlink' => 'tulaika',
'editsectionhint' => 'Tulaika i patte: $1',
'toc' => 'Guihana',
'showtoc' => "na'anok",
'hidetoc' => "nå'na'",
'thisisdeleted' => "Atan pat tuma'lo $1?",
'viewdeleted' => 'Atan $1?',
'restorelink' => '{{PLURAL:$1|unu na tinilaika mafnas|$1 na tinilaika siha manmafnas}}',
'feedlinks' => 'Liña:',
'site-rss-feed' => 'Liña RSS $1',
'site-atom-feed' => 'Liña Atom $1',
'page-rss-feed' => '"$1" i Liña RSS',
'page-atom-feed' => 'Liña Atom  "$1"',
'red-link-title' => "$1 (ti matuge')",

# Short words for each namespace, by default used in the namespace tab in monobook
'nstab-main' => 'Påhina',
'nstab-user' => "Påhina muna'sesetbi",
'nstab-media' => 'Påhinan media',
'nstab-special' => 'Påhina espesiat',
'nstab-project' => 'Påhinan proyekto',
'nstab-image' => 'Atkibu',
'nstab-mediawiki' => 'Mensahe',
'nstab-template' => 'Plantiyas',
'nstab-help' => 'Påhinan ayudo',
'nstab-category' => 'Katigoria',

# Main script and global functions
'nosuchaction' => "Tåya' na aksion taiguenao",
'nosuchspecialpage' => "Tåya' na påhinan espesiat taiguenao",

# General errors
'error' => 'Linachi',
'laggedslavemode' => "Adahi: Buente ha' tataigue i tinilaika gi halacha.",
'missing-article' => 'Ti ha sodda\' i database i palabras i pahina ni debi di u sodda\', i mafa\'na\'an "$1" $2.

Tenga, masusesedi este yanggen un klik i ti fafacho\'cho\' na diff pat historia na inachetton i pahina ni mana\'suha.

Yanggen ti este i rason, buente mañodda\' hao "bug" gi "software".

Pot fabot ripotta este para un [[Special:ListUsers/sysop|administrator]], ya un nota i URL.',
'missingarticle-rev' => '(tinilaika#: $1)',
'missingarticle-diff' => '(Dif: $1, $2)',
'internalerror' => 'Linachi sanhalom',
'filecopyerror' => 'Ti siña u kopia i atkibu "$1" para "$2".',
'filerenameerror' => 'Ti siña u tulaika i na\'an atkibu "$1" para "$2".',
'filedeleteerror' => 'Ti siña u na\'suha i atkibu "$1".',
'directorycreateerror' => 'Ti siña u fa\'tinas i direktorio "$1".',
'filenotfound' => 'Ti siña u sodda\' i atkibu "$1".',
'fileexistserror' => 'Ti siña u tuge\' i atkibu "$1": guåha esta i atkibu',
'unexpected' => 'Ti ma\'antisipa i guinaha: "$1"="$2".',
'badtitle' => 'Båba na titulo',
'viewsource' => 'Atan i code',
'viewsourcetext' => "Siña un li'e' yan kopia i code ni påhina:",
'namespaceprotected' => "Ti nahong nibet-mu petmisu tumulaika i påhina siha ni mafa'na'an '''$1'''.",
'ns-specialprotected' => 'Ti siña un tulaika i manespesiat na påhina.',
'titleprotected' => "Prinetehi este na titulo ginen fina'tinas-ña as  [[User:$1|$1]].
Ha nå'i i rason ''$2''.",

# Login and logout pages
'logouttext' => "'''Malog-out hao på'go.'''

Siña hao kumontinua manu'usa {{SITENAME}} sin nå'an, pat siña uma'log ta'lo pat siña un usa otra na nå'an muna'sesetbi.
Fanapunta na pålu na påhina siha para u na'annok na ma'log-in hao, asta ki un funas iyo-mu browser cache.",
'yourname' => "Nå'an ni muna'setbi:",
'yourpassword' => 'Password:',
'yourpasswordagain' => "Taip ta'lo i password:",
'remembermypassword' => "Na'hasso iyo-ku login gi este na komputer (for a maximum of $1 {{PLURAL:$1|day|days}})",
'yourdomainname' => 'Lugat-mu:',
'login' => 'Log in',
'nav-login-createaccount' => "Hålom / fa'tinas kuenta-mu",
'loginprompt' => "Un nesita muna'sedi cookies para un log in gi {{SITENAME}}.",
'userlogin' => "Hålom / fa'tinas kuenta-mu",
'logout' => 'Log out',
'userlogout' => 'Log out',
'notloggedin' => 'Ti malogin',
'nologin' => "Tåya' iyo-mu login? '''$1'''.",
'nologinlink' => "Fama'tinas kuenta",
'createaccount' => "Fa'tinas kuenta-hu",
'gotaccount' => "Guåha esta kuenta-mu? '''$1'''.",
'gotaccountlink' => 'Log in',
'createaccountmail' => 'gi e-mail',
'badretype' => "Ti parehu i password siha ni un po'lo.",
'userexists' => "Esta guåha na u'usa enao na nå'an muna'sesetbi.
Ayek fan otru na nå'an.",
'loginerror' => 'Lachi gi login',
'nocookiesnew' => "Mafa'tinas i kuentan muna'sesetbi, lao ti malogin hao.
Manusa {{SITENAME}} cookies para muna'login muna'sesetbi siha.
Ti mansedi hao ni cookies.
Pot fabot na'sedi ha', pues log in yan i na'an-mu muna'sesetbi yan password.",
'nocookieslogin' => "Manusa {{SITENAME}} cookies para muna'login muna'sesetbi siha.
Ti mansedi hao ni cookies.
Pot fabot na'sedi ha'.",
'noname' => "Ti mangge' hao ni na'an muna'sesetbi ni ma'sedi.",
'loginsuccesstitle' => 'Munhåyan i login',
'loginsuccess' => "'''Esta ma'log in hao gi {{SITENAME}}: \"\$1\".'''",
'nosuchuser' => 'Tåya\' na muna\'sesetbi as "$1".
Chek fan i dineletrea, pat fa\'tinas un kuenta nuebu.',
'nosuchusershort' => 'Tåya\' na muna\'sesetbi as "$1".
Chek fan i dineletrea.',
'nouserspecified' => "Un nesita manayek i na'an muna'sesetbi.",
'wrongpassword' => "Lachi i password ni tinige'-mu. Pot fabot, chagi fan ta'lo.",
'wrongpasswordempty' => "Ti mamo'lu hao password. Pot fabot, chagi fan ta'lo.",
'passwordtooshort' => "Lachi pat mampos kadada' iyo-mu password.
Na'seguro na mas ki {{PLURAL:$1|1 na letra|$1 na letras}} ha' ya ti parehu ha' yan i na'an-mu muna'setbi.",
'mailmypassword' => 'E-mail password neu',
'passwordremindertitle' => 'I nuebu na password temporårio para {{SITENAME}}',
'passwordremindertext' => 'Guåha na mamaisen (hågu ha\' buente, ginen i IP $1)
na para in na\'hanague hao ni password nuebu para {{SITENAME}} ($4).
Matulaika i password i muna\'sesetbi as "$2" para "$3".
Debi di un log in ya un tulaika i password ensigidas.

Yanggen ti hagu ha\' na mamaisen pat yanggen un hasso ni password (ya munga hao tumulaika), siña un iknora este na mensahe ya un usa i password-mu mas bihu.',
'noemail' => "Tåya' e-mail address tinige' papa' ni muna'sesetbi as \"\$1\".",
'passwordsent' => 'Mana\'hanague hao ni password nuebu gi iyo-mu e-mail address ni marehistra nu "$1".
Pot fabot na\'log in despues di un recibi ha\'.',
'blocked-mailpassword' => "Machomma' i IP-mu tumulaika påhina, ya ti masedi ha usa i fonksion manlaknos password ya u fanåtaha mama'baba.",
'eauthentsent' => "Mana'hanague i e-mail address ni tinige'-mu ni konfitmasion.
Åntes di mana'hanague i kuenta ni otru e-mail, debi di un tattiyi i chinachalani gi halom e-mail, para mankonfotme na magahet na kuenta-mu ha.",
'acct_creation_throttle_hit' => "Despensa, guåha esta $1 na kuenta-mu.
Ti siña hao fama'tinas mas.",
'emailauthenticated' => "Mana'seguro iyo-mu e-mail address gi $1.",
'emailnotauthenticated' => "Ti mana'seguro iyo-mu e-mail address trabiha.
Ti para u na'hanao ni sigienti na inayek siha.",
'noemailprefs' => "Ayek fan e-mail address para un na'sedi este na inayek siha.",
'emailconfirmlink' => 'Konfitme iyo-mu e-mail',
'accountcreated' => "Mafa'tinas i kuenta",
'accountcreatedtext' => "Mafa'tinas i kuentan muna'sesetbi nu $1.",
'createaccount-title' => "Nina'huyong kuenta nu {{SITENAME}}",
'loginlanguagelabel' => 'Lengguahe: $1',

# Change password dialog
'oldpassword' => 'Password bihu:',
'newpassword' => 'Password nuebu:',
'retypenew' => "Na'tekla nuebu na password:",
'resetpass_submit' => "Po'lo i password ya log in",

# Edit page toolbar
'bold_sample' => "Tinige' potpot",
'bold_tip' => "Tinige' potpot",
'italic_sample' => "Tinige' mana'echong",
'italic_tip' => "Tinige' mana'echong",
'link_sample' => 'Titulon inachetton',
'link_tip' => 'Inachetton sanhalom',
'extlink_sample' => 'http://www.example.com titulon inachetton',
'extlink_tip' => 'Inachetton sanhiyong (munga mamalefa ni http://)',
'headline_sample' => "Tinige' i titulo mo'na",
'headline_tip' => "Titulon nibet mina'dos",
'nowiki_tip' => 'Iknora i estrokturan wiki',
'image_tip' => "Mana'halom na atkibu",
'media_tip' => 'Inachetton atkibu',
'sig_tip' => 'Fitma-mu yan i ora',
'hr_tip' => "Råya ni umadespatta (uho' fan)",

# Edit pages
'summary' => 'Sumaria:',
'subject' => "Suhetu/titulo mo'na:",
'minoredit' => "Dikike' este na tiniliaka",
'watchthis' => 'Pulan este na påhina',
'savearticle' => 'Såtba i påhina',
'preview' => 'Ripasu',
'showpreview' => "Fa'nu'i para manripasa",
'showdiff' => "Na'annok tinilaika",
'anoneditwarning' => "'''Adahi:''' Ti ma log-in hao.
Mausa iyo-mu IP address sempre para tumulaika i historian påhina este.",
'missingsummary' => "'''Nina'hasso:''' Tåya' iyo-mu sumaria tinilaika.
An un yemme' Såtba ta'lo, para u såtba i tinilaika-mu sin sumaria.",
'missingcommenttext' => "Nå'ye kommentu gi papa'.",
'missingcommentheader' => "'''Nina'hasso:''' Ti un tuge' suhetu/titulon må'gas para i kommentu.
Yanggen un yemme' \"Såtba\" ta'lo, masåtba tinilaika-mu sin titulo.",
'summary-preview' => 'Ripasun sumaria:',
'subject-preview' => 'Ripasun suhetu/titulo:',
'blockedtitle' => "Machoma' i muna'sesetbi",
'blockedtext' => "'''Machomma' i na'an-mu muna'sesetbi pat IP-mu.'''

Manchomma' as $1.
Pot i rason: ''$2''.

* Matutuhon manchomma' gi: $8
* Para u funhayan manchomma' gi: $6
* Håyi para u chomma': $7

Siña un kuentusi si $1 pat otru na [[{{MediaWiki:Grouppage-sysop}}|administradot]] para un diskuti i chinemma'.
Ti siña un usa i ramientan 'e-mail i muna'sesetbi,' solo guåha e-mail address minaolek gi i [[Special:Preferences|priferensia i kuenta-mu]] ya ti machomma' hao manu'usa ha'.
På'go, $3 iyo-mu IP, ya machomma' i ID #$5.
Pot fabot, na'hålom i infotmasion gi sanhilo' gi i finaisen-mu siha.",
'autoblockedtext' => "Machomma' på'go iyo-mu IP sa' guåha otru na muna'sestbi ni ha u'usa ha', ya machomma' gue' as $1.
Ha na'i i rason:

:''$2''

* Matutuhon manchomma' gi: $8
* Para u funhåyan manchomma' gi: $6

Siña un kuentusi si $1 pat otru na [[{{MediaWiki:Grouppage-sysop}}|administradot]] para un diskuti i chinemma'.

Ti siña un usa i ramientan 'e-mail i muna'sesetbi,' solo guåha e-mail address minaolek gi i [[Special:Preferences|priferensia i kuenta-mu]] ya ti machomma' hao manu'usa ha'.

Machomma' i ID #$5.
Pot fabot, na'hålom i ID gi todus i finaisen-mu siha.",
'blockednoreason' => "ti mana'i rason",
'whitelistedittext' => 'Un nesisita ma$1 para tumulaika påhina.',
'confirmedittext' => "Un nesisita un konfotme iyo-mu email åntes di tumulaika påhina.
Pot fabot po'lo yan konfotme iyo-mu e-mail gi [[Special:Preferences|prifirensia muna'sesetbi]].",
'nosuchsectiontitle' => "Tåya' na påtte",
'nosuchsectiontext' => "Tåya' na påtte ni un chagi tumulaika.",
'loginreqtitle' => 'Manesita login',
'loginreqlink' => 'log in',
'loginreqpagetext' => "Debi di un $1 para manli'e' påhina.",
'accmailtitle' => "Mana'hanague ni password.",
'accmailtext' => 'Mana\'hanague $2 ni password "$1".',
'newarticle' => '(Nuebu)',
'newarticletext' => "Tåya' na påhina trabiha ni inachetton ni un yemme'.
Para un fa'tinas i påhina, fångge' gi sanpapa' na kahon (bisita i [[{{MediaWiki:Helppage}}|påhinan ayudo]] para mas infotmasion).
Anggen lachi finatto-mu mågi, yemme' i batunes '''back''' ni iyo-mu browser.",
'anontalkpagetext' => "----''Este na påhinan kombetsasion muna'sesetbi taina'an ni ti ha fa'tinas kuenta-ña pat ti ha u'usa i kuenta. Entonses na in i'isa i numiron IP para in aidentifika gue'.
Buente ha' na guåha unos kuantos na muna'sesetbi ni ma u'usa i enao na IP.
An un muna'sesetbi taina'an hao ya manñiente hao na guåha na kommentu ti prisisu ni manadirihiyi hao, pot fabot [[Special:UserLogin|fa'tinas kuenta-mu pat log in]] para mansuhayi yinaoyao yan i otru na muna'sesetbi siha.''",
'noarticletext' => 'Tåya\' tinige\'-ña este na påhina gi este na momento.
Siña un [[Special:Search/{{PAGENAME}}|aligao este na titulon påhina]] gi halom otro na påhina siha, <span class="plainlinks">[{{fullurl:{{FULLPAGENAME}}|action=edit}} tulaika este na påhina]</span>.',
'userpage-userdoesnotexist' => 'Ti marehistra i kuenata muna\'sesetbi "<nowiki>$1</nowiki>". Pot fabot chek kao malago\' hao un fa\'tinas/tulaika este na påhina.',
'usercsspreview' => "'''Hasso fan na un ripapasa iyo-mu CSS muna'sesetbi, trabiha ti masåtba ha'!'''",
'userjspreview' => "'''Hasso fan na un chachagi/ripapasa iyo-mu JavaScript muna'sesetbi, trabiha ti masåtba ha'!'''",
'note' => "'''Fanapunta:'''",
'previewnote' => "'''Annok este para manripasa;
ti masåtba trabiha i tinilaika-mu!'''",
'previewconflict' => "Este na ripasu ha na'annok i tinige' gi i kahon tumulaika gi sanhilo' kumu para u annok an un såtba ha'.",
'session_fail_preview' => "'''Dispensa! Ti siña in na'fo'na i tinilaika-mu sa' guåha fina'lingun infotmasion sesion.
Pot fabot chagi ta'lo. Yanggen ti siña u såtba ta'lo, chagi muna'logout yan na'login ta'lo.'''",
'editing' => 'Tumulaika $1',
'editingsection' => 'Tumulaika $1 (patte)',
'editingcomment' => 'Tulalaika $1 (komentu)',
'editconflict' => 'Tulaika i problema: $1',
'explainconflict' => "Guåha otru na tinilaika gi påhina ginen i tiempon tumutuhon hao tumulaika.
Ma'annok i tinige' gi hilo' komu på'go.
Ma'annok i tinilaika-mu gi papa'.
Para un nesita muna'daña i tinilaika-mu yan i guinaha.
'''I tinige' gi hilo' ha'''' para u såtba annai un yemme' \"{{int:savearticle}}\".",
'yourtext' => "Tinige'-mu",
'storedversion' => 'Tinilaika masåtba',
'editingold' => "'''ADAHI: Un tulalaika un ribision påhina gus bihu.
Yanggen un såtba ha', para u fana'malingu i tinilaika siha despues di enao na ribision.'''",
'yourdiff' => 'Diferensia',
'copyrightwarning' => "Pot fabot, fanapunta fan na makonsidera manmasotta todus i kontribusion gi {{SITENAME}} papa' i $2 (atan $1 para i attikulu siha).
Yanggen munga hao na matulaika i tinige'-mu yan malamaña ya mana'apåttao ta'lo maseha månu, pues munga ma po'lu guini.<br />
Un promette ham lokkue' na hågu ha' i tituge', pat un kopia ha' gi un lugat publika pat otru na lugat dibåtde.
'''MUNGA MANFA'BURESI NA GAIDIRECHU I MANTITUGE'!'''",
'copyrightwarning2' => "Pot fabot, fanapunta fan na siña i otru na muna'sesetbi siha tumulaika/munasuha todus i kontribusion gi {{SITENAME}}.
Yanggen munga hao na matulaika i tinige'-mu yan malamaña ya mana'apåttao ta'lo maseha månu, pues munga ma po'lu guini.<br />
Un promette ham lokkue' na hågu ha' i tituge', pat un kopia ha' gi un lugat publika pat otru na lugat dibåtde (atan $1 para i attikulu siha).
'''MUNGA MANFA'BURESI NA GAIDIRECHU I MANTITUGE'!'''",
'templatesused' => "I plantiyas siha ni ma'usa gi påhina:",
'templatesusedpreview' => "I {{PLURAL:$1|plantiya|plantiyas}} ni ma'usa gi ripasu:",
'templatesusedsection' => "Plantiyas siha ni ma'usa gi este na seksion:",
'template-protected' => '(maprotehi)',
'hiddencategories' => "Miembron {{PLURAL:$1|1 manå'na' na kategoria|$1 na mannå'na' na kategoria}} este na påhina:",
'nocreatetext' => "I nina'siña mama'tinas mannuebu na påhina machomma' gi {{SITENAME}}.
Siña hao humanao tåtte ya tumulaika påhina ni guinaha, pat [[Special:UserLogin|log in pat un fa'tinas kuenta-mu]].",
'nocreate-loggedin' => "Ti nahon i nibet-mu petmisu mama'tinas nuebu na påhina gi {{SITENAME}}.",
'permissionserrors' => 'Linache siha gi Petmisu',
'permissionserrorstext' => "Ti nahong nibet-mu petmisu chumo'gue enao, pot i sigiente {{PLURAL:$1|na rason|na rason siha}}:",
'permissionserrorstext-withaction' => "Ti nahong nibet-mu petmisu $2, sa' i sigiente {{PLURAL:$1|na rason|na rason siha}}:",
'recreate-moveddeleted-warn' => "'''Adahi: Esta mana'suha i påhina ni para un fa'tinas ta'lo.'''

Konsidera fan anggen maolek ha' kumontinua tumulaika i påhina.
Estague' i historian muna'suha ni påhina:",

# Parser/template warnings
'expensive-parserfunction-warning' => "Adahi: Guåha meggai mampos na inagang fongksion parser.

Debi di menos ki $2 ha', på'go guåha $1.",
'expensive-parserfunction-category' => 'Påhinas siha ni meggai mampos na inagang fungksion parser',
'post-expand-template-inclusion-warning' => "Adahi: Mampos dangkolo i mineddong muna'saonao plantiyas.
Ti para u na'saonao palu na plantiyas.",
'post-expand-template-inclusion-category' => "Påhina siha ni maloffan i mineddong muna'saonao plantiyas",

# Account creation failure
'cantcreateaccounttitle' => "Ti siña mama'tinas kuenta",
'cantcreateaccount-text' => "Chinemma' mama'tinas kuenta ginen i IP ('''$1''') as [[User:$3|$3]].

Nina'i i rasion ''$2'' as $3",

# History pages
'viewpagelogs' => 'Atan i historian påhina',
'nohistory' => "Tåya' historian tinilaika este na påhina.",
'currentrev' => 'Tinilaika modetnu',
'revisionasof' => 'Maribisa ginen $1',
'revision-info' => 'Tinilaika ginen $1 as $2',
'previousrevision' => "←Ribision mas amko'",
'nextrevision' => 'Mas nuebu na tinilaika→',
'currentrevisionlink' => 'I mas nuebu na tinilaika',
'cur' => "på'go",
'next' => 'manmamaila',
'last' => 'halacha',
'page_first' => "fine'nena",
'page_last' => 'uttimo',
'histlegend' => "Seleksion ni diferensia: ayek i kahon rediu siha ni tinilaika ni para un akompara ya yemme' \"enter\" pat i batunes gi sanpapa'.<br />
Leyendu: (på'go) = i diferensia yan i rebision på'go,
(halacha) = i diferensia yan i tinilaika ma'pos, M = dikike' na tinilaika.",
'histfirst' => 'I mas bihu',
'histlast' => 'I mas nuebu',
'historysize' => '({{PLURAL:$1|1 byte|$1 bytes}})',
'historyempty' => '(taisinahguan)',

# Revision feed
'history-feed-title' => 'Historian tinilaika',
'history-feed-description' => 'Historian tinilaika gi este na påhina gi wiki',
'history-feed-item-nocomment' => '$1 gi $2',
'history-feed-empty' => "Tåya' na påhina ni finaisen-mu.
Buente mana'suha gi wiki, pat matulaika nå'an-ña.
Chagi fan [[Special:Search|manaligao gi wiki]] para i mannuebu na påhina siha ni manaplikao.",

# Revision deletion
'rev-deleted-comment' => "(mana'suha kommentu)",
'rev-deleted-user' => "(mana'suha nå'an muna'sesetbi)",
'rev-deleted-event' => "(mana'suha aksion log)",
'rev-deleted-text-permission' => "Mana'suha este na tinilaika ginen i manpubliku na atkibu siha.
Fana'an guåha attikulo gi [{{fullurl:{{#Special:Log}}/suppress|page={{FULLPAGENAMEE}}}} log muna'susuha].",
'rev-deleted-text-view' => "Mana'suha este na tinilaika ginen i mampubliku na atkibu siha.
Komu administradot {{SITENAME}} siña un atan ha';
fana'an guåha attikulo gi [{{fullurl:{{#Special:Log}}/suppress|page={{FULLPAGENAMEE}}}} log muna'susuha].",
'rev-delundel' => "na'annok/nå'na'",
'revisiondelete' => "Na'suha/para håfa muna'suha i tinilaika",
'revdelete-selected' => "'''{{PLURAL:$2|Tinilaika ma'ayek|Tinilaika manma'ayek}} gi [[:$1]]:'''",
'logdelete-selected' => "'''{{PLURAL:$1|Kasun log ni ma'ayek|Kasun log ni manma'ayek}}:'''",
'revdelete-legend' => "Po'lo i chinemma' lini'e'on siha",
'revdelete-hide-text' => "Nå'na' i tinige' ribision",
'revdelete-hide-image' => "Nå'na' i sinahguan atkibu",
'revdelete-hide-comment' => "Nå'na' i kommentun tinilaika",
'revdelete-hide-user' => "Nå'na' i na'an muna'sesetbi/IP i editot",
'revdelete-unsuppress' => "Na'suha i chinemma' siha gi tinilaika manmana'lo siha",
'revdelete-log' => 'Rason:',
'revdelete-submit' => "Na'aplika gi tinilaika ni ma'ayek",
'revdelete-success' => "'''Munhåyan i sinesedi i lini'e'on ribision .'''",
'logdelete-success' => "'''Munhåyan i sinesedi i lini'e'on log.'''",
'revdel-restore' => "Tulaika i lini'e'on",
'pagehist' => 'Historian påhina',
'deletedhist' => "Historia mana'suha",

# Suppression log
'suppressionlog' => "Log manchinemma'",

# History merging
'mergehistory' => "Na'daña i historian i påhina siha",
'mergehistory-header' => "Sinedi hao ni este na påhina muna'daña i historian unu na påhinan mo'na yan otru na påhina mas nuebu.
Na'seguro na este na tinilaika para u mantiene i kinontinua i historian påhiana.",
'mergehistory-box' => "Na'daña i ribision siha i dos påhina:",
'mergehistory-from' => "Påhina mo'na:",
'mergehistory-into' => 'Påhina destinasion:',
'mergehistory-list' => 'I historian tinilaika dañayon',
'mergehistory-merge' => "Siña u fana'daña [[:$2]] yan i mansigiente na ribision [[:$1]].
Usa i kalumnan batunes rediu para mana'daña solo i ribision siha ni manmafa'tinas gi/åntes di i oran espesifiku.
Fanapunta na para u na'nuebu i kolumna anggen un usa i inachetton nabegasion.",
'mergehistory-go' => "Na'annok i mandañayon na tinilaika siha",
'mergehistory-submit' => "Na'daña i ribision siha",
'mergehistory-empty' => "Tåya' mandañayon na ribision siha.",
'mergehistory-success' => "Munhåyan muna'daña [[:$2]] yan i $3 {{PLURAL:$3|na ribision|na ribision siha}} gi [[:$1]].",
'mergehistory-fail' => "Ti siña muna'daña i historia siha, pot fabot ripåra ta'lo i påhina yan i ora pine'lo.",
'mergehistory-no-source' => "Tåya' na påhina mo'na $1.",
'mergehistory-no-destination' => "Tåya' na påhina destinasion $1.",
'mergehistory-invalid-source' => "I påhina mo'na debi di maolek na titulo.",
'mergehistory-invalid-destination' => 'I påhina destinasion debi di maolek na titulo.',
'mergehistory-autocomment' => "Mana'daña [[:$1]] yan [[:$2]]",
'mergehistory-comment' => "Mana'daña [[:$1]] yan [[:$2]]: $3",

# Merge log
'mergelog' => "Log i manmana'daña",
'pagemerge-logentry' => "ha na'daña [[$1]] yan [[$2]] (ribision asta $3)",
'revertmerge' => 'Sipåra',
'mergelogpagetext' => "Guåha gi sampapa' un listan i manmana'daña siha ni historian påhina gi halacha.",

# Diffs
'history-title' => 'Historian tinilaika nu "$1"',
'lineno' => 'Liña $1:',
'compareselectedversions' => "Akompara i tinilaika siha ma'ayek",
'editundo' => 'funas',
'diff-multi' => "({{PLURAL:$1|Ti mana'a'annok unu na tinilaika gi talo'|Ti manmana'a'annok $1 na tinilaika siha gi talo'}}.)",

# Search results
'searchresults' => 'Humuyongña i inaligao',
'searchresults-title' => 'Risutton i inaligao "$1"',
'searchresulttext' => 'Para mas infotmasion nu manaliligao {{SITENAME}}, hånao para [[{{MediaWiki:Helppage}}|{{int:help}}]].',
'searchsubtitle' => "Un aligao '''[[:$1]]'''",
'searchsubtitleinvalid' => "Un aligao '''$1'''",
'toomanymatches' => 'Mampos meggai na manaya ni humuyongña, pot fabot chagi difirente na inaligao',
'titlematches' => 'Titulon påhina siha ni manaya',
'notitlematches' => "Tåya' titulon påhina siha ni manaya",
'textmatches' => "Tinige' påhina siha ni manaya",
'notextmatches' => "Tåya' na tinige' påhina siha ni manaya",
'prevn' => "{{PLURAL:$1|$1}} ni manmå'pos",
'nextn' => "{{PLURAL:$1|$1}} ni manmamaila'",
'viewprevnext' => 'Atan i ($1 {{int:pipe-separator}} $2) ($3)',
'search-result-size' => '$1 ({{PLURAL:$2|1 na palabra|$2 na palabra siha}})',
'search-result-score' => 'Prinisisu: $1%',
'search-redirect' => "(na'dirihi $1)",
'search-section' => '(påtte $1)',
'search-suggest' => 'Kao kumekeilek-mu: $1',
'search-interwiki-caption' => 'Proyektu siha ni mamarehu',
'search-interwiki-default' => 'Humuyongña gi $1:',
'search-interwiki-more' => '(mas)',
'search-relatedarticle' => 'Umachetton',
'mwsuggest-disable' => "Na'påra i abisan AJAX",
'searchrelated' => 'umachetton',
'searchall' => 'todu',
'showingresults' => "A'annok gi sampapa' asta {{PLURAL:$1|'''1''' na humuyongña|'''$1''' na humuyongña siha}} tumutuhon yan i #'''$2'''.",
'showingresultsnum' => "A'annok gi sampapa' {{PLURAL:$3|'''1''' na humuyongña|'''$3''' na humuyongña siha}} tumutuhon yan i #'''$2'''.",
'nonefound' => "'''Apunta''': Solo ha' manmanaligao palu na sågan nå'an. Chagi fan muna'klå'an mo'na i inaligao-mu yan ''all:'' para un aligao todu i guinaha (kontodu påhinan kombesasion, plantiyas, etc), pat usa i sagan nå'an ni malago'-mu kumu klå'an mo'na.",
'powersearch' => 'Finu na inaligao',
'powersearch-legend' => 'Finu na inaligao',
'powersearch-ns' => "Inaligao gi sagan nå'an:",
'powersearch-redir' => "Na'lista i na'dirihi siha",
'powersearch-field' => 'Aligao',
'search-external' => 'Inaligao sanhiyong',
'searchdisabled' => "Mana'påra i inaligao {{SITENAME}}.
Siña hao manaligao gi Google gi entretanto.
Fanapunta na fana'an ti gus nuebu i listan-ñiha i guinahan {{SITENAME}}.",

# Preferences page
'preferences' => "I ga'ña-mu",
'mypreferences' => "I ga'ña-hu",
'prefs-edits' => 'Numirun tinilaika:',
'prefsnologin' => "Ti ma'log in",
'prefsnologintext' => "Un nesisita [[Special:UserLogin|muna'log in]] para un tulaika i ga'ña-mu muna'sesetbi.",
'changepassword' => 'Tulaika password',
'prefs-skin' => 'Låssas',
'skin-preview' => "Na'annok",
'datedefault' => "Tåya' prifirensia",
'prefs-datetime' => 'Fecha yan ora',
'prefs-personal' => "Botta muna'sesetbi",
'prefs-rc' => 'Tinilaika gi halacha',
'prefs-watchlist' => 'Listan pinilan',
'prefs-watchlist-days' => "Dihas siha muna'annok gi listan pinilan:",
'prefs-watchlist-edits' => "I mas takhilo' na numirun tinilaika para u na'annok gi i mana'la'dangkolo i listan pinilan:",
'prefs-misc' => 'Misc',
'saveprefs' => 'Såtba',
'resetprefs' => "Na'funas i tinilaika ti manma'såtba siha",
'prefs-editing' => 'Tumulaika',
'rows' => 'Fila siha:',
'columns' => 'Kolumna siha:',
'searchresultshead' => 'Aligao',
'resultsperpage' => 'Dinanche siha kada påhina:',
'recentchangesdays' => "Diha siha na para u na'annok gi i tinilaika gi halacha:",
'recentchangescount' => "Kunatu na tinilaika para u na'annok gi i tinilaika gi halacha:",
'savedprefs' => "Manmaasåtba i ga'ña-mu siha.",
'allowemail' => "Na'sedi e-mail ginen otru na muna'sesetbi siha",
'prefs-searchoptions' => 'Inayek manaligao siha',
'prefs-namespaces' => "Sågan nå'an",
'defaultns' => "Fanaligao hålom este na sågan nå'an fine'nena:",
'default' => 'default',
'prefs-files' => 'Atkibu siha',
'youremail' => 'E-mail:',
'username' => "Nå'an muna'sesetbi:",
'uid' => "ID muna'sesetbi:",
'prefs-memberingroups' => 'Miembron {{PLURAL:$1|i grupu|i grupu siha}}:',
'yourrealname' => "Minagahet nå'an-mu:",
'yourlanguage' => 'Lengguahe:',
'yournick' => 'Fitma:',
'badsig' => 'Ti maolek i fitma raw; chek i HTML tags.',
'badsiglength' => "Mampos anakko'-ña i na'an;
na'lakadada' $1 {{PLURAL:$1|na simbolo|na simbolo siha}}.",
'email' => 'E-mail',
'prefs-help-realname' => "Ti nesisario i na'an-mu mågahet.
Yanggen un decidi mamo'lu, ma'usa ha' sempre para muna'i hao ni kreditu ni che'cho'-mu.",
'prefs-help-email' => "Ti nesesario i e-mail address, lao ha na'sede otru na taotao siha kumentusi hao ni påhina-mu muna'sesetbi/kombetsasion sin mana'annoki siha ni aidentifikasion-mu.",
'prefs-help-email-required' => 'Nesisario i e-mail address.',

# User rights
'userrights' => "Inenkåtgan i direchun muna'sesetbi",
'userrights-lookup-user' => "Maneha i grupun muna'sesetbi",
'userrights-user-editname' => "Po'lo nå'an muna'sesetbi:",
'editusergroup' => "Tulaika grupun muna'sesetbi",
'userrights-editusergroup' => "Tulaika grupun muna'sesetbi",
'saveusergroups' => "Såtba Grupun Muna'sesetbi",
'userrights-groupsmember' => 'Miembron:',

# Groups
'group' => 'Grupu:',

'grouppage-sysop' => '{{ns:project}}:Atministradot siha',

# User rights log
'rightslog' => "I log ni direchun muna'sesetbi",

# Recent changes
'nchanges' => '$1 {{PLURAL:$1|na tinilaika|na tinilaika siha}}',
'recentchanges' => 'Tinilaika siha gi halacha',
'rcnote' => "Guåha {{PLURAL:$1|'''1''' na tinilaika|'''$1''' na tinilaika siha}} gi {{PLURAL:$2|day|'''$2''' days}}, ginen $5, $4.",
'rcnotefrom' => "Gi papa' guåha i tinilaika siha ginen '''$2''' (fa'na'an '''$1''' ma'annok).",
'rclistfrom' => "Na'annok i mannuebun tinilaika siha ginen $1",
'rcshowhideminor' => "$1 na mandikike' na tinilaika siha",
'rcshowhidebots' => '$1 na bots siha',
'rcshowhideliu' => "$1 na muna'sesetbi ni ma log in",
'rcshowhideanons' => "$1 i muna'sesetbi taina'an",
'rcshowhidemine' => '$1 na tinilaika-hu',
'rclinks' => "Na'annok na $1 tinilaika siha ginen $2 na dihas manmaloffan<br />$3",
'diff' => 'dif',
'hist' => 'hist',
'hide' => "Nå'na'",
'show' => "Na'annok",
'minoreditletter' => 'm',
'newpageletter' => 'N',
'boteditletter' => 'b',

# Recent changes linked
'recentchangeslinked' => 'Umachetton na tinilaika siha',
'recentchangeslinked-feed' => 'Umachetton na tinilaika siha',
'recentchangeslinked-toolbox' => 'Umachetton na tinilaika siha',
'recentchangeslinked-title' => 'Tinilaika pumarehu yan "$1"',
'recentchangeslinked-summary' => "Lista este ni tinilaika siha gi halacha ginen un påhina ma'ayek (pat ni miembro siha ginen un katigoria ma'ayek).
'''Potpot''' i påhina siha ginen [[Special:Watchlist|Listan pinilan-mu]].",
'recentchangeslinked-page' => "Nå'an i påhina:",

# Upload
'upload' => "Na'kåtga hulu' i atkibu",
'uploadbtn' => "Na'kåtga hulu' atkibu",
'uploadlogpage' => "Na'kåtga i log",
'uploadedimage' => 'mana\'kåtga hulu\' "[[$1]]"',

# Special:ListFiles
'listfiles' => 'Listan atkibu',

# File description page
'file-anchor-link' => 'Atkibu',
'filehist' => 'Historian atkibu',
'filehist-help' => "Yemme' i fecha/ora para un li'e' i atkibu annai annok guihi na momentu.",
'filehist-current' => "pa'go",
'filehist-datetime' => 'Fecha/Ora',
'filehist-user' => "Muna'sesetbi",
'filehist-dimensions' => 'Mineddong',
'filehist-filesize' => 'Mineddong atkibu',
'filehist-comment' => 'Komentu',
'imagelinks' => 'Inachetton dokumento',
'linkstoimage' => 'Umachetton i sigiente {{PLURAL:$1|na påhina|$1 na påhina siha}} yan este na atkibu:',
'nolinkstoimage' => "Tåya' na påhina siha umachetton yan este na atkibu.",
'sharedupload' => "Ma'apatte este na atkibu ya buente ha' ma'usa gi otru proyektu siha.",
'uploadnewversion-linktext' => "Na'kåtga hulu' un tinilaikan atkibu mas nuebu",

# MIME search
'mimesearch' => 'Inaligao MIME',

# List redirects
'listredirects' => "Na'lista eyu i manmadirihi ta'lo",

# Unused templates
'unusedtemplates' => "Plantiyas siha ti ma'usa",

# Random page
'randompage' => 'Maseha håfa na påhina',

# Random redirect
'randomredirect' => "Muna'dirihi maseha manu guatu",

# Statistics
'statistics-mostpopular' => "Påhina siha ni mas ma'atan",

'doubleredirects' => "Mandoble na inachetton ma'dirihi siha",

'brokenredirects' => "Manmayulang na muna'dirihi siha",
'brokenredirects-edit' => 'tulaika',

'withoutinterwiki' => "Påhina siha tai'inachetton ni lengguahe",

'fewestrevisions' => "I påhina siha ni guåha mas didide' na tinilaika",

# Miscellaneous special pages
'nbytes' => '$1 {{PLURAL:$1|byte|bytes}}',
'nlinks' => '$1 {{PLURAL:$1|na inachetton|na inachetton siha}}',
'nmembers' => '$1 {{PLURAL:$1|na miembro|na miembro siha}}',
'lonelypages' => "Påhinan manmayute'",
'uncategorizedpages' => 'Påhina siha taikatigoria',
'uncategorizedcategories' => "Katigoria siha ti manmana'katigoria",
'uncategorizedimages' => "Atkibu siha ti manmana'katigoria",
'uncategorizedtemplates' => 'Plantiyas siha taikatigoria',
'unusedcategories' => "Katigoria siha ti manma'usa",
'unusedimages' => "Atkibu siha ti manma'usa",
'wantedcategories' => "Manmalago' na katigoria siha",
'wantedpages' => "Manmalago' na påhina siha",
'mostlinked' => 'Påhina siha ni mas umachetton',
'mostlinkedcategories' => 'Katigoria siha ni mas umachetton',
'mostlinkedtemplates' => 'Plantiyas siha ni mas umachetton',
'mostcategories' => 'Påhina siha ni mas meggai na katigoria',
'mostimages' => 'Aktibu siha ni mas umachetton',
'mostrevisions' => 'Påhina siha ni mas meggai na tinilaika',
'shortpages' => "Mankadada' na påhina siha",
'longpages' => "I mananåkko' na påhina siha",
'deadendpages' => 'Påhina siha ni taiinachetton',
'protectedpages' => 'Påhina siha ni manmaprotehi',
'listusers' => "Listan muna'sesetbi",
'newpages' => 'Mannuebu na påhina siha',
'ancientpages' => 'I mas manbihu na påhina siha',
'move' => 'Kånya',
'movethispage' => 'Kånya i påhina',

# Book sources
'booksources' => 'I source i lepblo',
'booksources-go' => 'Hånao',

# Special:Log
'specialloguserlabel' => "Muna'sesetbi:",
'speciallogtitlelabel' => 'Titulo:',
'log' => 'Logs',
'all-logs-page' => 'Todu i logs siha',

# Special:AllPages
'allpages' => 'Todu i påhina siha',
'alphaindexline' => '$1 para $2',
'nextpage' => "Mamaila' na påhina ($1)",
'prevpage' => "Må'pos na påhina ($1)",
'allpagesfrom' => "Fa'nu'i i påhina siha tumutuhon gi:",
'allarticles' => 'Todu i påhina siha',
'allpagessubmit' => 'Hånao',
'allpagesprefix' => "Na'annok i påhina siha yan i kla'an mo'na:",

# Special:Categories
'categories' => 'Katigoria',
'categoriespagetext' => 'Guåha påhina pat media gi halom i sigiente katigoria.
[[Special:UnusedCategories|Unused categories]] are not shown here.
Also see [[Special:WantedCategories|wanted categories]].',
'special-categories-sort-count' => 'såttea pot tinefong',
'special-categories-sort-abc' => 'såttea pot i atfabetu',

# Special:LinkSearch
'linksearch-ok' => 'Aligao',

# Email user
'emailuser' => "Na'e-mail i muna'sesetbi este",

# Watchlist
'watchlist' => 'Listan pinilan-hu',
'mywatchlist' => 'Listan pinilan-hu',
'addedwatchtext' => "Mana'suha i påhina \"[[:\$1]]\" para iyo-mu [[Special:Watchlist|Listan pinilan]].
I tinilaika siha mo'na gi tiempo kontodu i påhinan kombetsasion siha para u fana'lista guihi, yan para u '''na'potpot''' i påhina gi halom [[Special:RecentChanges|i listan tinilaika gi halacha]] para un ayek ha' mas libianu.",
'removedwatchtext' => 'Mana\'suha i påhinan "[[:$1]]" gi [[Special:Watchlist|listan pinilan-mu]].',
'watch' => 'Pulan',
'watchthispage' => 'Pulan este na påhina',
'unwatch' => 'Basta mapulan',
'watchlist-details' => '{{PLURAL:$1|$1 påhina|$1 na påhina siha}} un pupulan, sin i påhinan kombetsasion siha.',
'wlshowlast' => "Na'annok $1 na ora yan $2 na diha siha gi halacha $3",

# Displayed when you click the "watch" button and it is in the process of watching
'watching' => 'Mamulan...',
'unwatching' => 'Pumapara mamulan...',

# Delete
'deletepage' => "Na'suha i påhina",
'historywarning' => "Adahi: Guåha historia-ña ni påhina na para un na'suha:",
'confirmdeletetext' => "Para un na'suha i påhina kontodu i historia-ña.
Konfotme fan na este i malago'-mu, na kumonprende hao hiniyong-ña, yan tumattiyi [[{{MediaWiki:Policy-url}}|i polisia]] ni bidada-mu.",
'actioncomplete' => 'Funhayan i aksion',
'deletedtext' => 'Mana\'suha "$1".
Chek $2 para i historian muna\'suha gi halacha.',
'dellogpage' => "Historian muna'suha",
'deletecomment' => 'Rason:',
'deleteotherreason' => 'Otru na rason:',
'deletereasonotherlist' => 'Otru rason',

# Rollback
'rollbacklink' => 'tulaika tatte',

# Protect
'protectlogpage' => 'I historian proteksion',
'prot_1movedto2' => 'Makånya [[$1]] påra [[$2]]',
'protectcomment' => 'Rason:',
'protectexpiry' => 'Munhåyan:',
'protect_expiry_invalid' => 'Lachi i oran funhåyan.',
'protect_expiry_old' => 'Esta maloffan i oran funhåyan.',
'protect-text' => "Siña un tulaika i nibet proteksion ni påhina '''$1'''.",
'protect-locked-access' => "Ti nahong i petmisu kuenta-mu tumulaika nibet proteksion ni påhina siha.
Estague taiguini i nibet i påhina '''$1''':",
'protect-fallback' => 'Afuetsas "$1" na petmisu',
'protect-level-autoconfirmed' => "Chomma' i muna'sesetbi siha ti manma'rehistra",
'protect-expiring' => 'munhåyan gi $1 (UTC)',
'protect-cantedit' => "Ti siña un tulaika i nibet proteksion ni påhina, sa' ti nahong i petmisu-mu tumulaika.",
'restriction-type' => 'Petmisu:',
'restriction-level' => 'Nibet opbligao:',

# Restrictions (nouns)
'restriction-edit' => 'Tulaika',

# Undelete
'undeletebtn' => "Fa'tinas ta'lo",
'undeletelink' => 'atan/rinueba',
'undelete-search-submit' => 'Aligao',

# Namespace form on various pages
'namespace' => "Sågan nå'an:",
'invert' => 'Bira i sileksion',
'blanknamespace' => '(Fanhaluman)',

# Contributions
'contributions' => "Kontribusion siha ni muna'sesetbi",
'mycontris' => 'Kontribusion-hu',
'contribsub2' => 'Para $1 ($2)',
'uctop' => "(sanhilo')",
'month' => 'Ginen i mes (yan eståba):',
'year' => 'Ginen i sakkan (yan eståba):',

'sp-contributions-newbies-sub' => 'Para i mannuebu na kuenta siha',
'sp-contributions-blocklog' => "Na'påra i log",
'sp-contributions-talk' => 'Kuentusi',
'sp-contributions-submit' => 'Aligao',

# What links here
'whatlinkshere' => "Håfa ha na'chetton guini",
'whatlinkshere-title' => 'I påhina siha ni mana\'chetton yan "$1"',
'linkshere' => "Umachetton i sigienten påhina siha yan '''[[:$1]]''':",
'nolinkshere' => "Taya' umachetton yan '''[[:$1]]'''.",
'isredirect' => 'dirihi i påhina',
'istemplate' => 'sinaonao',
'whatlinkshere-prev' => "{{PLURAL:$1|ni må'pos|$1 ni manmå'pos}}",
'whatlinkshere-next' => "{{PLURAL:$1|ni mamaila'|$1 ni manmamaila'}}",
'whatlinkshere-links' => '← inachetton',

# Block/unblock
'blockip' => "Chomma' i muna'sesetbi",
'ipboptions' => "2 oras:2 hours,1 diha:1 day,3 na diha siha:3 days,1 simana:1 week,2 na simana siha:2 weeks,1 mes:1 month,3 na mes siha:3 months,6 na mes siha:6 months,1 sakkan:1 year,taifinakpo':infinite",
'ipblocklist' => "IP yan na'an muna'sesetbi ni manmachomma' siha",
'ipblocklist-submit' => 'Aligao',
'blocklink' => "chomma'",
'unblocklink' => "båsta machomma'",
'contribslink' => 'kontrib',
'blocklogpage' => "Log ni manmachomma'",
'blocklogentry' => "ha chomma' [[$1]] ya u funhayan gi $2 $3",

# Move page
'movepagetext' => "U'usa i sigiente fotma para u matulaika i na'an i påhina, tumulaika historia-ña para i nuebu na nå'an.
Para u madirihi i titulon orihinåt para i nuebu.
Siña ha' un tulaika i påhina siha ni manmadirihi guatu i titulon orihinåt.
Yanggen munga hao, na'seguro na un chek i pahinan madirihi [[Special:DoubleRedirects|doble]] pat [[Special:BrokenRedirects|manmayamak]] siha.
Hågu ha' responsible muna'seguro na manmakontinua para i destinasion-ñiha i inachetton siha.

Fanapunta fan na anggen guåha esta otru påhina mafa'na'an i titulo nuebu, '''ti''' para makånya i påhina, solu tåya' ha' gi sanhalom destinasion pat tåya' historia-ña tinilika eyu ni mana'dirihi.
Kumeke'ilek-ña este na siña un tulaika tatte i na'an i påhina an guåha linachi-mu, ya ti siña un na'overwrite i påhina siha ni manggaige esta.

'''Adahi!'''
Fa'na'an tinilaika dinidok yan ti maekspekta sempre anggen mageftungo' i påhina;
na'seguro fan na un komprende i humuyongña i bidada-mu sempre.",
'movepagetalktext' => "Para u kånya i påhinan kombetsasion ni i påhina \"solo:\"
*Guåha esta un påhinan kombetsasion ni parehu i na'an-ña, pat
*Un funas i matka gi sanpapa' na kahon.

Pot sienkasu i hilo', nesesario ha' na un kånya pat un na'daña i påhina yanggen malago'-mu.",
'movearticle' => 'Kånya i påhina:',
'newtitle' => 'Para i nuebu na titulo:',
'move-watch' => 'Pulan este na påhina',
'movepagebtn' => 'Kånya i påhina',
'pagemovedsub' => 'Munhåyan i siniha',
'movepage-moved' => '\'\'\'Makånya "$1" para "$2"\'\'\'',
'articleexists' => "Esta guåha un påhina mafa'na'an enao, pat ti masedi ni inayek-mu.
Ayek fan otru nå'an-ña.",
'talkexists' => "'''Munhåyan i siniha i påhina mismo, lao ti siña ha kånya i påhinan kombetsasion sa' guåha esta otru ni titulon nuebu.'''",
'movedto' => 'makånya para',
'movetalk' => 'Kånya i påhinan kombetsasion',
'movelogpage' => 'Kånya i log',
'movereason' => 'Rason:',
'revertmove' => 'tulaika tatte',

# Export
'export' => 'Manekspotta påhina',

# Namespace 8 related
'allmessages' => 'Mensahen sistema siha',

# Thumbnails
'thumbnail-more' => "Na'lamoddong",
'thumbnail_error' => "Guåha na linachi mama'titinas i thumbnail: $1",

# Import log
'importlogpage' => 'Impotta i log',

# Tooltip help for the actions
'tooltip-pt-userpage' => "I påhina-mu i muna'sesetbi",
'tooltip-pt-mytalk' => 'Kometsasion-hu',
'tooltip-pt-preferences' => "I ga'ña-hu",
'tooltip-pt-watchlist' => 'I listan påhina siha ni un pupulan.',
'tooltip-pt-mycontris' => 'Listan kontribusion-hu',
'tooltip-pt-login' => "Maolek-ña mohon yanggen humålom hao kuenta-mu, lao ti nesisariu ha'.",
'tooltip-pt-logout' => 'Log out',
'tooltip-ca-talk' => 'Diskuti i infotmasion i påhina',
'tooltip-ca-edit' => 'Siña un tulaika este na påhina. Pot fabot usa i batunes ni manchek åntes di un satba.',
'tooltip-ca-addsection' => "Nå'ye komentu gi kometsasion.",
'tooltip-ca-viewsource' => "Maprotehi i påhina. Siña un li'e' iyo-ña code.",
'tooltip-ca-history' => 'I uttimo siha na tinilaika para este na påhina',
'tooltip-ca-protect' => 'Protehi i påhina este',
'tooltip-ca-delete' => "Na'suha i påhina",
'tooltip-ca-move' => 'Kånya i påhina',
'tooltip-ca-watch' => "Po'lu i påhina este gi listan pinilan-hu",
'tooltip-ca-unwatch' => "Na'suha i påhina gi i listan pinilan-mu",
'tooltip-search' => 'Aligao gi {{SITENAME}}',
'tooltip-search-go' => "Ir na páhina'i e ma'nome si cumplido",
'tooltip-search-fulltext' => 'Aligao todu siha i pahina para este na palabras.',
'tooltip-p-logo' => 'Fanhaluman',
'tooltip-n-mainpage' => 'Bisita i Fanhaluman',
'tooltip-n-mainpage-description' => 'Bisita i prinsipat na pahina.',
'tooltip-n-portal' => "Pot i proyektu, håfa siña hao chumo'gue, månu na siña masodda' kosas",
'tooltip-n-currentevents' => 'Aligao infotmasion ni estorian modetnu siha',
'tooltip-n-recentchanges' => "I listan ina'go i wiki gi halacha.",
'tooltip-n-randompage' => "Ta'yoki guatu maseha håfa na påhina",
'tooltip-n-help' => "Estegue' siña hao kumunprende.",
'tooltip-t-whatlinkshere' => "Listan todu i påhinan wiki siha ni ma na'chetton guini",
'tooltip-t-recentchangeslinked' => 'I tinilaika siha gi halacha gi todu pahina ni ha ma-link ginen este na pahina.',
'tooltip-t-contributions' => "Atan i listan kontribusion siha ni este na muna'sesetbi",
'tooltip-t-emailuser' => "Na'hanague i muna'sesetbi ni e-mail",
'tooltip-t-upload' => "Na'kåtga hulu' atkibu",
'tooltip-t-specialpages' => 'Lista ni manespesiat na påhina',
'tooltip-t-print' => "I emprentåyon na pinila' este na påhina.",
'tooltip-t-permalink' => 'I petmanente na inachetton para este na tinilaikan i påhina.',
'tooltip-ca-nstab-user' => "Atan i påhina ni muna'sesetbi",
'tooltip-ca-nstab-special' => 'Espesiat este na påhina, ti siña un tulaika i mismo påhina.',
'tooltip-ca-nstab-project' => 'Atan i påhinan proyekto',
'tooltip-ca-nstab-image' => 'Atan i påhinan atkibu',
'tooltip-ca-nstab-template' => 'Atan i plantiyas',
'tooltip-ca-nstab-help' => 'Atan i påhinan ayudo',
'tooltip-ca-nstab-category' => 'Atan i påhinan katigoria',
'tooltip-minoredit' => "Na'matka este kalan dikike' na tinilaika",
'tooltip-save' => 'Satba tinilaika-mu',
'tooltip-preview' => 'Chek håfa un tulaika, usa este fan åntes di un såtba i pahina!',
'tooltip-diff' => "Na'annok håfa i tinilaika-mu gi tinige'",
'tooltip-compareselectedversions' => "Na'annok i diferensia siha gi i dos ma'ayek na tinilaika ni påhina.",
'tooltip-watch' => "Po'lo i påhina gi listan pinilan-mu",

# Browsing diffs
'previousdiff' => "← I må'pos na dif",
'nextdiff' => "Mamaila' na dif →",

# Media information
'file-info-size' => '$1 × $2 na pixel, mineddong atkibu: $3, MIME klåsi: $4',
'file-nohires' => "Tåya' mas takhilo' na risolusion.",
'svg-long-desc' => 'Atkibu SVG, $1 × $2 na pixels, mineddong atkibu: $3',
'show-big-image' => 'Magåhet mineddong-ña',

# Special:NewFiles
'newimages' => 'Galarian atkibu mannuebu siha',
'ilsubmit' => 'Aligao',

# Bad image list
'bad_image_list' => "Estague' i plantiyas:

I manmana'lista na attikulu siha ha' (i liña siha yan * gi sanme'na) para u konsidera.
Nesesario ha' na'chetton i fine'nena na liña yan un atkibu båba.
Ti mantattiyi i areklo ni sigienten ina'chetton siha gi mismo liña, i.e. i påhina siha ni masedi mamo'lu atkibu gi halom i liña.",

# Metadata
'metadata' => 'Metadata',
'metadata-expand' => "Na'annok todu i infotmasion-ña",
'metadata-collapse' => "Na'atok patte i infotmasion-ña",

# External editor support
'edit-externally' => 'Tulaika i atkibu yan un aplikasion sanhiyong',
'edit-externally-help' => 'Hånao para [//www.mediawiki.org/wiki/Manual:External_editors i plantan chinachalani] para mas infotmasion.',

# 'all' in various places, this might be different for inflected languages
'watchlistall2' => 'todu',
'namespacesall' => 'todu',
'monthsall' => 'todu',

# Multipage image navigation
'imgmultigo' => 'Hånao!',

# Table pager
'table_pager_limit_submit' => 'Hånao',

# Watchlist editing tools
'watchlisttools-view' => 'Atan i mampettanesi na tinilaika siha',
'watchlisttools-edit' => 'Atan ya tulaika i listan pinilan',
'watchlisttools-raw' => "Tulaika i listan pinilan ti mana'finu",

# Special:Version
'version' => 'Tinilaika',
'version-specialpages' => 'Manespesiat na påhina',

# Special:FileDuplicateSearch
'fileduplicatesearch-submit' => 'Aligao',

# Special:SpecialPages
'specialpages' => 'Manespesiat na påhina',

);
